==> haskell-mmorph-1.1.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmorph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmorph
version:              1.1.3
visibility:           public
id:                   mmorph-1.1.3-JCMpsrUvhnr1NOPkDZRyaY
key:                  mmorph-1.1.3-JCMpsrUvhnr1NOPkDZRyaY
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Monad morphisms
description:
    This library provides monad morphism utilities, most commonly used
    for manipulating monad transformer stacks.

category:             Control
abi:                  c1deb4c1713a5ac869f819a360003d87
exposed:              True
exposed-modules:      Control.Monad.Morph Control.Monad.Trans.Compose
import-dirs:          /usr/lib/ghc-8.8.1/site-local/mmorph-1.1.3
library-dirs:         /usr/lib/ghc-8.8.1/site-local/mmorph-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/mmorph-1.1.3
hs-libraries:         HSmmorph-1.1.3-JCMpsrUvhnr1NOPkDZRyaY
depends:
    base-4.13.0.0 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.5-JSMUn8oEOEx4KSfZBSghWS

haddock-interfaces:   /usr/share/doc/haskell-mmorph/html/mmorph.haddock
haddock-html:         /usr/share/doc/haskell-mmorph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmorph-1.1.3-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmorph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmorph
version:              1.1.3
visibility:           public
id:                   mmorph-1.1.3-5OY1P7burDtCMi7lCbauVL
key:                  mmorph-1.1.3-5OY1P7burDtCMi7lCbauVL
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Monad morphisms
description:
    This library provides monad morphism utilities, most commonly used
    for manipulating monad transformer stacks.

category:             Control
abi:                  412dbaab9fbe8fcad44c427f2befcb8d
exposed:              True
exposed-modules:      Control.Monad.Morph Control.Monad.Trans.Compose
import-dirs:          /usr/lib/ghc-8.10.1/site-local/mmorph-1.1.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/mmorph-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/mmorph-1.1.3
hs-libraries:         HSmmorph-1.1.3-5OY1P7burDtCMi7lCbauVL
depends:
    base-4.14.0.0 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi

haddock-interfaces:   /usr/share/doc/haskell-mmorph/html/mmorph.haddock
haddock-html:         /usr/share/doc/haskell-mmorph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
